#include <uC++.h>
#include <iostream>
using std::cout;
using std::endl;

volatile bool stop = false;

_Task T {
    void main() {
	while ( ! stop ) {
	    yield();
	}
    }
};

void uMain::main() {
    uProcessor *p2 = NULL;
    {
	T t[2];

	uProcessor *p1 = new uProcessor();

	while ( &uThisProcessor() != p1 ) {
	    yield();
	} // while

	p2 = new uProcessor();

//	delete p2;
	delete p1;

	stop = true;
    }
    cout << "here" << endl;
    delete p2;
} // uMain::main

// Local Variables: //
// compile-command: "../../bin/u++ -g -multi Processor.cc" //
// End: //
